@@ -1,31 +1,22 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/13/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the UIInfo class used to represent the object and editor content of
     an active Traits-based user interface.
 """
 
-
-
 from traits.api import HasPrivateTraits, Instance, Constant, Bool
 
 
 class UIInfo(HasPrivateTraits):
-    """ Represents the object and editor content of an active Traits-based
+    """Represents the object and editor content of an active Traits-based
     user interface
     """
 
@@ -40,15 +31,14 @@ class UIInfo(HasPrivateTraits):
     initialized = Bool(False)
 
     def bind_context(self):
-        """ Binds all of the associated context objects as traits of the
-            object.
+        """Binds all of the associated context objects as traits of the
+        object.
         """
         for name, value in self.ui.context.items():
             self.bind(name, value)
 
     def bind(self, name, value, id=None):
-        """ Binds a name to a value if it is not already bound.
-        """
+        """Binds a name to a value if it is not already bound."""
         if id is None:
             id = name
 
