@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -31,8 +31,7 @@ from .constants import WindowColor, OKColor, ErrorColor
 
 
 class Editor(UIEditor):
-    """ Base class for wxPython editors for Traits-based UIs.
-    """
+    """Base class for wxPython editors for Traits-based UIs."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -45,45 +44,29 @@ class Editor(UIEditor):
     border_size = Int(4)
 
     def _control_changed(self, control):
-        """ Handles the **control** trait being set.
-        """
+        """Handles the **control** trait being set."""
         if control is not None:
             control._editor = self
 
     def set_focus(self):
-        """ Assigns focus to the editor's underlying toolkit widget.
-        """
+        """Assigns focus to the editor's underlying toolkit widget."""
         if self.control is not None:
             self.control.SetFocus()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         new_value = self.str_value
         if self.control.GetValue() != new_value:
             self.control.SetValue(new_value)
 
-    def error(self, excp):
-        """ Handles an error that occurs while setting the object's trait value.
-        """
-        dlg = wx.MessageDialog(
-            self.control,
-            str(excp),
-            self.description + " value error",
-            wx.OK | wx.ICON_INFORMATION,
-        )
-        dlg.ShowModal()
-        dlg.Destroy()
-
     def set_tooltip_text(self, control, text):
-        """ Sets the tooltip for a specified control.
-        """
+        """Sets the tooltip for a specified control."""
         control.SetToolTip(text)
 
     def _enabled_changed(self, enabled):
-        """ Handles the **enabled** state of the editor being changed.
-        """
+        """Handles the **enabled** state of the editor being changed."""
         control = self.control
         if control is not None:
             control.Enable(enabled)
@@ -93,8 +76,7 @@ class Editor(UIEditor):
             self.label_control.Refresh()
 
     def _visible_changed(self, visible):
-        """ Handles the **visible** state of the editor being changed.
-        """
+        """Handles the **visible** state of the editor being changed."""
         control = self.control
         parent = control.GetParent()
 
@@ -123,18 +105,15 @@ class Editor(UIEditor):
                 parent.Layout()
 
     def get_error_control(self):
-        """ Returns the editor's control for indicating error status.
-        """
+        """Returns the editor's control for indicating error status."""
         return self.control
 
     def in_error_state(self):
-        """ Returns whether or not the editor is in an error state.
-        """
+        """Returns whether or not the editor is in an error state."""
         return False
 
     def set_error_state(self, state=None, control=None):
-        """ Sets the editor's current error state.
-        """
+        """Sets the editor's current error state."""
         if state is None:
             state = self.invalid
         state = state or self.in_error_state()
@@ -161,14 +140,12 @@ class Editor(UIEditor):
             item.Refresh()
 
     def _invalid_changed(self, state):
-        """ Handles the editor's invalid state changing.
-        """
+        """Handles the editor's invalid state changing."""
         self.set_error_state()
 
 
 class EditorWithList(Editor):
-    """ Editor for an object that contains a list.
-    """
+    """Editor for an object that contains a list."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -184,14 +161,15 @@ class EditorWithList(Editor):
     list_value = Callable()
 
     def init(self, parent):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         factory = self.factory
         name = factory.name
         if name != "":
-            self.list_object, self.list_name, self.list_value = self.parse_extended_name(
-                name
-            )
+            (
+                self.list_object,
+                self.list_name,
+                self.list_value,
+            ) = self.parse_extended_name(name)
         else:
             self.list_object, self.list_name = factory, "values"
             self.list_value = lambda: factory.values
@@ -203,8 +181,7 @@ class EditorWithList(Editor):
         self._list_updated()
 
     def dispose(self):
-        """ Disconnects the listeners set up by the constructor.
-        """
+        """Disconnects the listeners set up by the constructor."""
         self.list_object.on_trait_change(
             self._list_updated, self.list_name + "[]", remove=True
         )
@@ -212,23 +189,19 @@ class EditorWithList(Editor):
         super().dispose()
 
     def _list_updated(self):
-        """ Handles the monitored trait being updated.
-        """
+        """Handles the monitored trait being updated."""
         self.list_updated(self.list_value())
 
     def list_updated(self, values):
-        """ Handles the monitored list being updated.
-        """
+        """Handles the monitored list being updated."""
         raise NotImplementedError
 
 
 class EditorFromView(Editor):
-    """ An editor generated from a View object.
-    """
+    """An editor generated from a View object."""
 
     def init(self, parent):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         self._ui = ui = self.init_ui(parent)
         if ui.history is None:
             ui.history = self.ui.history
@@ -236,22 +209,21 @@ class EditorFromView(Editor):
         self.control = ui.control
 
     def init_ui(self, parent):
-        """ Creates and returns the traits UI defined by this editor.
-            (Must be overridden by a subclass).
+        """Creates and returns the traits UI defined by this editor.
+        (Must be overridden by a subclass).
         """
         raise NotImplementedError
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         # Normally nothing needs to be done here, since it should all be handled
         # by the editor's internally created traits UI:
         pass
 
     def dispose(self):
-        """ Disposes of the editor.
-        """
+        """Disposes of the editor."""
         self._ui.dispose()
 
         super().dispose()
